import { useEffect, useState } from 'react'
import withLayout from '@/layout'
import Taro from '@tarojs/taro'
import { ScrollView, Image } from '@tarojs/components'
import ProjectListItem from '@/components/ProjectListItem/index'
import { queryBrandInfo } from '@/services/common';
import { getItemList } from '@/services/item';
import { getImgURL } from '@/utils/image'
import '@/assets/css/iconfont.css'
import ColumnTitle from '../components/ColumnTitle/index'
import './index.scss'

export default withLayout((props) => {
  const { router } = props
  const { id } = router.params

  const [ProjectList, setProjectList] = useState([{}, {}])
  const [brandInfo, setBrandInfo] = useState({})

  const getList = (params) => {
    Taro.showLoading()
    getItemList({
      brandId: id,
      ...(params || {}),
    }).then((res) => {
      const { records } = res
      setProjectList(records || {})
      Taro.hideLoading()
    }).catch((err) => {
      console.error(err)
      Taro.hideLoading()
    })
  }

  useEffect(() => {
    if (id) {
      queryBrandInfo(id).then((res) => {
        setBrandInfo(res || {})
      }).catch((err) => {
        console.error(err)
      })

      getList({ pageNumber: 1 })
    }
  }, [id])

  return (
    <view className='brandDetail'>
      <ScrollView scroll-y>
        <view className='Content'>

          {/* 主图 */}
          <view className='Top'>
            <Image mode='scaleToFill' src={getImgURL(brandInfo.brandImg)} className='centerLabel'></Image>
          </view>

          {/* 简介 */}
          <view className='Desc'>
            <view>
              <Image mode='heightFix' src={getImgURL(brandInfo.brandLogo)} className='Logo'></Image>
              <view>
                <text>{brandInfo.brandRemark}</text>
              </view>
            </view>
          </view>

          {/* 在售项目 */}
          <view className='AllProject'>
            <ColumnTitle Name='在售项目' Icon='icon-aixin' ShowMore ToMore={() => { Taro.navigateTo({ url: `/pages/index/buildingList/index` }) }}></ColumnTitle>
            <view className='ProjectList'>
              {
                ProjectList.map((item, index) => (
                  <ProjectListItem Data={item} key={`ProjectListItem-${index}`}></ProjectListItem>
                ))
              }
            </view>
          </view>

          {/* bottom */}
          <view className='PageBottom'>
            <text>已经到底了~</text>
          </view>

        </view>
      </ScrollView>
    </view>
  );
});
