import { useState, useEffect } from 'react'
import withLayout from '@/layout'
import { ScrollView } from '@tarojs/components'
import '@/assets/css/iconfont.css'
import { useSelector } from 'react-redux'
import { fetch } from '@/utils/request'
import { API_INDEX_PROJECTS } from '@/constants/api'
import ProjectListItem from '@/components/ProjectListItem/index'
import './index.scss'
import FilterForArea from './components/FilterForArea/index'
import FilterForPrice from './components/FilterForPrice/index'
import FilterForHouseType from './components/FilterForHouseType/index'
import FilterForMore from './components/FilterForMore/index'

export default withLayout(() => {

  const city = useSelector(state => state.city)
  const [PageList, setPageList] = useState([])
  const [pageNumber, setPageNumber] = useState(1)
  const [pageSize] = useState(10)
  const [IsPull, setPull] = useState(false)
  const [HasNextPage, setHasNextPage] = useState(true)
  const [FilterMenus] = useState([
    { name: '面积', id: 1 },
    { name: '价格', id: 2 },
    { name: '户型', id: 3 },
    { name: '更多', id: 4 }
  ])
  const [CurrentFilter, setCurrentFilter] = useState(null)
  const [FilterData, setFilterData] = useState({
    area: '-',
    price: '-',
    priceType: null,
    houseType: '-',
    buildingType: '-'
  })

  useEffect(() => {
    if (city.curCity.name) {
      GetProjectList()
    }
  }, [pageNumber, city])

  useEffect(() => {
    if(pageNumber === 1) {
      GetProjectList()
    } else {
      setPageNumber(1)
    }
  }, [FilterData])

  const GetProjectList = () => { // 获取项目列表
    setHasNextPage(false)
    let Data = {...FilterData}
    for(let key in Data) {
      Data[key] = Data[key] === '-' ? null : Data[key]
    }
    fetch({ url: API_INDEX_PROJECTS, method: 'get', payload: { cityId: city.curCity.id, pageNumber, pageSize, ...Data } }).then((res) => {
      setPageList(pageNumber === 1 ? res.records || [] : PageList.concat(res.records || []))
      setHasNextPage(res.current < res.pages)
      setPull(false)
      setCurrentFilter(null)
    }).catch(() => {
    })
  }

  const PageRefresh = () => { // 页面下拉刷新回调
    setPull(true)
  }

  const PageLoadMore = () => { // 页面上拉加载更多
    if (HasNextPage) {
      setPageNumber(pageNumber + 1)
    }
  }

  const CutFilter = (id) => {
    return () => {
      setCurrentFilter(id === CurrentFilter ? null : id)
    }
  }

  const FilterChange = (e) => {
    let Data = { ...FilterData }
    Data[e.name] = e.value
    setFilterData(Data)
  }

  const PriceChange = (e) => {
    let Data = { ...FilterData }
    for (let key in e) {
      Data[key] = e[key]
    }
    setFilterData(Data)
  }

  useEffect(() => { // 下拉刷新触发
    if (IsPull) {
      if (pageNumber === 1) {
        GetProjectList()
      } else {
        setPageNumber(1)
      }
    }
  }, [IsPull])

  return (
    <view className='Page buildingList flex-v'>

      <view className='Search'>
        <view>
          <text className='iconfont icon-sousuo'></text>
          <text>输入项目名称或直播标题</text>
        </view>
      </view>

      <view className='Filter'>
        <view className='flex-h'>
          {
            FilterMenus.map((item, index) => (
              <view className='flex-item' key={`FilterMenusItem-${index}`} onClick={CutFilter(item.id)}>
                <text>{item.name}</text>
                <text className={CurrentFilter === item.id ? 'iconfont icon-sanjiaoxingup' : 'iconfont icon-sanjiaoxingdown'}></text>
              </view>
            ))
          }
          <text className='iconfont icon-paixu Sort'></text>
        </view>
      </view>

      <view className='flex-item'>
        <view className='FilterContainer' style={{ display: !!CurrentFilter ? 'block' : 'none' }}>

          {/* 面积 */}
          {
            CurrentFilter === 1 &&
            <FilterForArea change={FilterChange} defaultValue={FilterData.area}></FilterForArea>
          }

          {/* 价格 */}
          {
            CurrentFilter === 2 &&
            <FilterForPrice change={PriceChange} priceType={FilterData.priceType} price={FilterData.price}></FilterForPrice>
          }

          {/* 户型 */}
          {
            CurrentFilter === 3 &&
            <FilterForHouseType change={FilterChange} defaultValue={FilterData.houseType}></FilterForHouseType>
          }

          {/* 更多 */}
          {
            CurrentFilter === 4 &&
            <FilterForMore change={FilterChange} defaultValue={FilterData.buildingType}></FilterForMore>
          }

        </view>
        <view className='ScrollContainer'>
          <ScrollView scroll-y refresher-enabled refresher-triggered={IsPull} onrefresherrefresh={PageRefresh} onscrolltolower={PageLoadMore} refresher-background='#fff'>
            <view className='PageContent'>
              <view className='ProjectList'>
                {
                  PageList.map((item, index) => (
                    <ProjectListItem Data={item} key={`ProjectListItem-${index}`}></ProjectListItem>
                  ))
                }
              </view>

              {/* bottom */}
              <view className='PageBottom'>
                <text>已经到底了~</text>
              </view>

            </view>
          </ScrollView>
        </view>
      </view>

    </view>
  )
})
