import { useState, useEffect } from 'react'
import { useSelector } from 'react-redux'
import Taro from '@tarojs/taro'
import { ScrollView } from '@tarojs/components'
import withLayout from '@/layout'
import ProjectListItem from '@/components/ProjectListItem/index'
import { fetch } from '@/utils/request'
import { API_BANNER_LIST, API_INDEX_PROJECTS } from '@/constants/api'

import Location from './components/Location/index'
import Banner from './components/Banner/index'
import Menu from './components/Menu/index'
import HotRecommend from './components/HotRecommend/index'
import LiveSale from './components/LiveSale/index'
import ColumnTitle from './components/ColumnTitle/index'

import './index.scss'

export default withLayout(() => {

  const city = useSelector(state => state.city)
  const [BannerList, setBannerList] = useState([])
  const [ProjectList, setProjectList] = useState([])
  const [IsPull, setPull] = useState(false)
  const [PullTimer, setPullTimer] = useState(null)
  const [ShowHotRecommend, setShowHotRecommend] = useState(false)
  const [ShowLive, setShowLive] = useState(false)

  useEffect(() => {
    if (city.curCity.name) {
      GetBanner()
      GetProjectList()
    }
  }, [city])

  const GetBanner = () => { // 获取banner
    fetch({ url: `${API_BANNER_LIST}/banner`, method: 'get', payload: { cityId: city.curCity.id, showPosition: 'index' } }).then((res) => {
      setBannerList(res || [])
    })
  }

  const GetProjectList = () => { // 获取项目列表
    fetch({ url: API_INDEX_PROJECTS, method: 'get', payload: { cityId: city.curCity.id, pageNum: 1, pageSize: 10 } }).then((res) => {
      setProjectList(res.records || [])
    })
  }

  const PageRefresh = () => { // 页面下拉刷新回调
    setPull(true)
  }

  const HotRecommendChange = (e) => {
    setShowHotRecommend(e)
  }

  const LiveChange = (e) => {
    setShowLive(e)
  }

  useEffect(() => { // 下拉刷新触发
    if (IsPull) {
      clearTimeout(PullTimer)
      setPullTimer(setTimeout(() => {
        setPull(false)
      }, 2000))
    }
  }, [IsPull])

  return (
    <view className='Page Index'>

      <ScrollView scroll-y refresher-enabled refresher-triggered={IsPull} onrefresherrefresh={PageRefresh} refresher-background='#fff'>
        <view className='PageContent'>

          {/* 定位 */}
          <view className='Location'>
            <Location></Location>
          </view>

          {/* banner */}
          <view className='Banner'>
            <view>
              <view>
                <Banner List={BannerList}></Banner>
              </view>
            </view>
          </view>

          {/* 菜单 */}
          <view className='Menu'>
            <Menu></Menu>
          </view>

          {/* 热门推荐 */}
          <view className='HotRecommend' style={{display: ShowHotRecommend ? 'block' : 'none'}}>
            <ColumnTitle Name='热门推荐' Icon='icon-shoucang'></ColumnTitle>
            <HotRecommend change={HotRecommendChange}></HotRecommend>
          </view>

          {/* 直播购房 */}
          <view className='LiveSale' style={{display: ShowLive ? 'block' : 'none'}}>
            <ColumnTitle Name='直播购房' Icon='icon-yinpin' ShowMore ToMore={() => { Taro.switchTab({ url: `/pages/video/index` }) }}></ColumnTitle>
            <LiveSale change={LiveChange}></LiveSale>
          </view>

          {/* 全部项目 */}
          <view className='AllProject'>
            <ColumnTitle Name='全部项目' Icon='icon-aixin' ShowMore ToMore={() => { Taro.navigateTo({ url: `/pages/index/buildingList/index` }) }}></ColumnTitle>
            <view className='ProjectList'>
              {
                ProjectList.map((item, index) => (
                  <ProjectListItem Data={item} key={`ProjectListItem-${index}`}></ProjectListItem>
                ))
              }
            </view>
          </view>

          {/* bottom */}
          <view className='PageBottom'>
            <text>已经到底了~</text>
          </view>

        </view>
      </ScrollView>

    </view>
  )
})
